@@ -6,7 +6,7 @@ from pathlib import Path
 from random import sample
 from ssl import SSLError
 from threading import current_thread
-from typing import Optional, Callable, Any, Dict, Union
+from typing import Optional, Callable, Any, Dict, Union, Iterable
 from uuid import uuid4 as uuid, UUID
 
 from arrow import Arrow, get as to_arrow, now
@@ -86,19 +86,16 @@ class Message:
     def __getitem__(self, key: str) -> Any:
         return self.contents[key]
 
-    @typechecked
     def keys(self):
         return self.contents.keys()
 
-    @typechecked
     def values(self):
         return self.contents.values()
 
     @typechecked
-    def __contains__(self, item):
+    def __contains__(self, item: str) -> bool:
         return item in self.contents
 
-    @typechecked
     def __iter__(self):
         return iter(self.contents)
 
